History
=======

1.1.1 (2019-03-07)
------------------

- Add enum34 dependency for Python 2.7.
- Minor bug fixes.

1.1.0 (2019-03-07)
------------------

- Added option to run tests selectively.
- Add support for Python 2.7, 3.4, and 3.5.

1.0 (2018-07-26)
----------------

- Added support for variable substitutions in script data.
- Added shortcuts for options in the specification file.
- Added --version option to command line arguments.
- Improved logging messages.

1.0a2 (2017-05-04)
------------------

- Switched configuration format from RSON to YAML.
- Added support for jailing test runs.
- Added option for test visibility in report.

1.0a1 (unreleased)
------------------

- First usable version.
